@@ -211,8 +211,16 @@ func (h *Handler) handleGetHeadPost(w http.ResponseWriter, r *http.Request) (sta
 	reqPath, status, err := h.stripPrefix(r.URL.Path)
 	if len(reqPath) > 0 && !strings.HasSuffix(reqPath, "/") {
 		strArr := strings.Split(reqPath, "/")
-		list, _ := aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
+
+		list, err := aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
+		if err != nil {
+			return http.StatusNotFound, err
+		}
+
 		fi, err = findUrl(strArr, h.Config.Token, h.Config.DriveId, list)
+		if err != nil || fi.FileId == "" {
+			return http.StatusNotFound, err
+		}
 		//url := fi.Thumbnail
 		//url := fi.Url
 		//if len(url) == 0 {
@@ -516,8 +524,10 @@ func (h *Handler) handleCopyMove(w http.ResponseWriter, r *http.Request) (status
 
 		if dstIndex == -1 {
 			dstIndex = 0
+		} else {
+			dstIndex += 1
 		}
-		aliyun.ReName(h.Config.Token, h.Config.DriveId, dst[dstIndex+1:], fi.FileId)
+		aliyun.ReName(h.Config.Token, h.Config.DriveId, dst[dstIndex:], fi.FileId)
 		return http.StatusNoContent, nil
 	}
 
@@ -732,27 +742,47 @@ func (h *Handler) handlePropfind(w http.ResponseWriter, r *http.Request) (status
 	var list model.FileListModel
 	var fi model.ListModel
 	fmt.Println(reqPath)
-	if reqPath == "markdown/" || (len(reqPath) > 0 && strings.HasSuffix(reqPath, "/")) {
+	var unfindListErr error
+	if len(reqPath) > 0 && strings.HasSuffix(reqPath, "/") {
 		dirName := strings.TrimRight(reqPath, "/")
 		dirName = strings.TrimLeft(dirName, "/")
 		list, err = aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
-
 		strArr := strings.Split(dirName, "/")
 		fi, _ = findUrl(strArr, h.Config.Token, h.Config.DriveId, list)
-		list, _ = findList(strArr, h.Config.Token, h.Config.DriveId)
+		list, unfindListErr = findList(strArr, h.Config.Token, h.Config.DriveId, fi.FileId)
 
 	} else if len(reqPath) == 0 {
 		list, err = aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
 		if err != nil {
 			//fmt.Println("获取列表失败")
 		}
-	} else if len(reqPath) > 0 && !strings.HasSuffix(reqPath, "/") {
-		if reqPath == "markdown" {
-			fmt.Print("markwo")
+		for _, fileInfo := range list.Items {
+			if fileInfo.Type == "folder" {
+				cache.GoCache.SetDefault(reqPath+fileInfo.Name, fileInfo.FileId)
+			}
 		}
+	} else if len(reqPath) > 0 && !strings.HasSuffix(reqPath, "/") {
 		strArr := strings.Split(reqPath, "/")
-		list, _ := aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
-		fi, _ = findUrl(strArr, h.Config.Token, h.Config.DriveId, list)
+		va, ok := cache.GoCache.Get(reqPath)
+		var value string
+		if ok {
+			value = va.(string)
+		} else {
+			value = ""
+		}
+		list, _ = aliyun.GetList(h.Config.Token, h.Config.DriveId, value)
+		for _, fileInfo := range list.Items {
+			if fileInfo.Type == "folder" {
+				cache.GoCache.SetDefault(reqPath+"/"+fileInfo.Name, fileInfo.FileId)
+			}
+		}
+		if len(list.Items) == 0 {
+			fi = aliyun.GetFileDetail(h.Config.Token, h.Config.DriveId, value)
+		} else {
+			//bugfix: use new local scope variable
+			list, _ := aliyun.GetList(h.Config.Token, h.Config.DriveId, "")
+			fi, _ = findUrl(strArr, h.Config.Token, h.Config.DriveId, list)
+		}
 	}
 
 	if err != nil {
@@ -761,7 +791,7 @@ func (h *Handler) handlePropfind(w http.ResponseWriter, r *http.Request) (status
 	ctx := r.Context()
 	if (err != nil || fi == model.ListModel{}) && reqPath != "" && reqPath != "/" && strings.Index(reqPath, "test.png") == -1 {
 		//新建或修改名称的时候需要判断是否已存在
-		if len(list.Items) == 0 {
+		if len(list.Items) == 0 || unfindListErr != nil {
 			return http.StatusNotFound, err
 		}
 
@@ -878,7 +908,7 @@ func (h *Handler) handlePropfind(w http.ResponseWriter, r *http.Request) (status
 			return err
 		}
 		href := path.Join(h.Prefix, parent.Name)
-		if parent.ParentFileId == "root" {
+		if parent.ParentFileId == "root" && parent.FileId == "" {
 			href = "/" + parent.Name
 		} else {
 			href, _ = aliyun.GetFilePath(h.Config.Token, h.Config.DriveId, parent.ParentFileId, parent.FileId, parent.Type)
@@ -886,8 +916,9 @@ func (h *Handler) handlePropfind(w http.ResponseWriter, r *http.Request) (status
 			if parent.Type == "folder" {
 				href += "/"
 			}
-		}
+			//list, _ = aliyun.GetList(h.Config.Token, h.Config.DriveId, parent.FileId)
 
+		}
 		return mw.write(makePropstatResponse(href, pstats))
 	}
 	userAgent := r.Header.Get("User-Agent")
@@ -958,19 +989,25 @@ func findUrl(strArr []string, token, driveId string, list model.FileListModel) (
 	return m, nil
 }
 
-func findList(strArr []string, token, driveId string) (model.FileListModel, error) {
+func findList(strArr []string, token, driveId string, parentId string) (model.FileListModel, error) {
 	var list model.FileListModel
-	list, _ = aliyun.GetList(token, driveId, "")
+	var err error
+	err = errors.New("未找到数据")
+	list, _ = aliyun.GetList(token, driveId, parentId)
+	num := 0
 	for _, a := range strArr {
 		for _, v := range list.Items {
 			if v.Name == a {
 				list, _ = aliyun.GetList(token, driveId, v.FileId)
+				num += 1
 				break
 			}
 		}
 	}
-
-	return list, nil
+	if num == len(strArr) {
+		err = nil
+	}
+	return list, err
 }
 
 func makePropstatResponse(href string, pstats []Propstat) *response {
